==> hqsoft_core-0.0.2.tar.gz: lib/data_base/url_api/root_url.dart <==
//Service Country
// ignore: non_constant_identifier_names
final String FINAL_API_URL_VN =
    'http://vnapi.nretail.asia'; //Real VN 'http://vnapi.nretail.asia'

// ignore: non_constant_identifier_names
final String FINAL_API_URL_DEV =
    'http://devapi.nretail.vn:8001'; //Dev 888.888.888.888.xxx :'http://devapi.nretail.vn:8001'

// ignore: non_constant_identifier_names
final String FINAL_API_URL_TEST =
    'http://apijjph.hqsoft.vn'; //Test 999.999.999.999.xxx:'http://apijjph.hqsoft.vn'

// ignore: non_constant_identifier_names
final String FINAL_API_URL_PH =
    'http://phapi.nretail.asia'; //'http://phapi.nretail.asia';
//Service Identity
// ignore: non_constant_identifier_names
final String ROOT_SERVICE_IDENTITY_URL =
    '/identityserver'; //FINAL_API_URL + '/identityserver';
// ignore: non_constant_identifier_names
final String ROOT_API_IDENTITY_URL = '$ROOT_SERVICE_IDENTITY_URL/Identity';
// ignore: non_constant_identifier_names
final String ROOT_API_ACCOUNT_URL = '$ROOT_SERVICE_IDENTITY_URL/Account';
// ignore: non_constant_identifier_names
final String ROOT_API_CONSUMER_URL = '$ROOT_SERVICE_IDENTITY_URL/Consumer';

//Service Master
final String prefix = "api";
final String version = "v1";

//Configuration
// ignore: non_constant_identifier_names
final String ROOT_API_CONFIGURATION_URL =
    '/catalog.api/$prefix/$version/Configuration';
// ignore: non_constant_identifier_names
final String ROOT_API_PROVINCE_URL = '/catalog.api/$prefix/$version/Province';
// ignore: non_constant_identifier_names
final String ROOT_API_DISTRICT_URL = '/catalog.api/$prefix/$version/District';
// ignore: non_constant_identifier_names
final String ROOT_API_WARD_URL = '/catalog.api/$prefix/$version/Ward';
// ignore: non_constant_identifier_names
final String ROOT_API_SHIP_ADDRESS_URL =
    '/catalog.api/$prefix/$version/ShipAddress';

//NOTIFY
// ignore: non_constant_identifier_names
final String ROOT_API_NOTIFY_URL =
    '/catalog.api/$prefix/$version/NotifyMessage';
// ignore: non_constant_identifier_names
final String ROOT_API_NOTIFICATION_SUP_URL =
    '/catalog.api/$prefix/$version/NotificationSetup';

//CATALOGS
// ignore: non_constant_identifier_names
final String ROOT_API_CATALOGS_URL = '/catalog.api/$prefix/$version';

//VENDOR
// ignore: non_constant_identifier_names
final String ROOT_API_VENDOR_URL = '/catalog.api/$prefix/$version/Vendor';
// ignore: non_constant_identifier_names
final String ROOT_API_VENDOR_CONN_SHOP_URL =
    '/catalog.api/$prefix/$version/VendorsConnectShops';

//CUMULATIVE_GIFTS
// ignore: non_constant_identifier_names
final String ROOT_API_CUMULATIVE_GIFTS_URL =
    '/catalog.api/$prefix/$version/CumulativeGifts';

//FEEDBACK
// ignore: non_constant_identifier_names
final String ROOT_API_FEEDBACK_URL = '/catalog.api/$prefix/$version/Feedback';

//Service Shop
// ignore: non_constant_identifier_names
final String ROOT_API_SHOP_URL = '/catalog.api/$prefix/$version/Shop';

//Service Basket
// ignore: non_constant_identifier_names
final String ROOT_API_CART_URL = '/basket.api/$prefix/$version/Basket';

//Service Order
// ignore: non_constant_identifier_names
final String ROOT_API_ORDER_URL = '/ordering.api/$prefix/$version/Orders';

//Service Price
// ignore: non_constant_identifier_names
final String ROOT_API_PRICING_URL = '/pricing.api/$prefix/$version';

//Service Price
// ignore: non_constant_identifier_names
final String ROOT_API_CHAT_URL = '/chat.api/$prefix/$version';

//Service Product Search Azure
// ignore: non_constant_identifier_names
final String ROOT_SERVICE_PRODUCT_SEARCH_AZURE_URL =
    'https://productsearch.search.windows.net/indexes';
// ignore: non_constant_identifier_names
final String ROOT_SERVICE_PRODUCT_SEARCH_URL = '/catalog.api/$prefix/$version';

//QUERY_PARAM
// ignore: non_constant_identifier_names
final String QUERY_PARAM_LINK = "/";
// ignore: non_constant_identifier_names
final String QUERY_PARAM_REQUEST = "/?";
// ignore: non_constant_identifier_names
final String QUERY_PARAM_REQUEST_QUESTION_MARK = "?";
// ignore: non_constant_identifier_names
final String QUERY_PARAM_EQUAL = "=";
// ignore: non_constant_identifier_names
final String QUERY_PARAM_AND = "&";
// ignore: non_constant_identifier_names
final String USERNAME_PARAM = "userName";
// ignore: non_constant_identifier_names
final String PASSWORD_PARAM = "password";
// ignore: non_constant_identifier_names
final String IMEI_PARAM = "imei";
// ignore: non_constant_identifier_names
final String LOCALTIME_PARAM = "localTime";
// ignore: non_constant_identifier_names
final String LANGID_PARAM = "langID";
// ignore: non_constant_identifier_names
final String CURRENT_PASSWORD_PARAM = "currentPassword";
// ignore: non_constant_identifier_names
final String NEW_PASSWORD_PARAM = "newPassword";
// ignore: non_constant_identifier_names
final String VERSION_PARAM = "version";
// ignore: non_constant_identifier_names
final String SESSIONID_PARAM = "sessionID";
// ignore: non_constant_identifier_names
final String DATE_PARAM = "date";
// ignore: non_constant_identifier_names
final String COUNTRY_CODE_PARAM = "countryCode";
// ignore: non_constant_identifier_names
final String PHONE_PARAM = "phone";
// ignore: non_constant_identifier_names
final String OTP_PARAM = "otp";

==> hqsoft_core-0.0.5.tar.gz: lib/data_base/url_api/root_url.dart <==
//Service Country
// ignore: non_constant_identifier_names
final String FINAL_API_URL_VN =
    'http://vnapi.nretail.asia'; //Real VN 'http://vnapi.nretail.asia'

// ignore: non_constant_identifier_names
final String FINAL_API_URL_DEV =
    'http://devapi.nretail.vn'; //Dev 888.888.888.888.xxx :'http://devapi.nretail.vn:8001'

// ignore: non_constant_identifier_names
final String FINAL_API_URL_TEST =
    'http://apijjph.hqsoft.vn'; //Test 999.999.999.999.xxx:'http://apijjph.hqsoft.vn'

// ignore: non_constant_identifier_names
final String FINAL_API_URL_PH =
    'http://phapi.nretail.asia'; //'http://phapi.nretail.asia';
//Service Identity
// ignore: non_constant_identifier_names
final String ROOT_SERVICE_IDENTITY_URL =
    '/identityserver'; //FINAL_API_URL + '/identityserver';
// ignore: non_constant_identifier_names
final String ROOT_API_IDENTITY_URL = '$ROOT_SERVICE_IDENTITY_URL/Identity';
// ignore: non_constant_identifier_names
final String ROOT_API_ACCOUNT_URL = '$ROOT_SERVICE_IDENTITY_URL/Account';
// ignore: non_constant_identifier_names
final String ROOT_API_CONSUMER_URL = '$ROOT_SERVICE_IDENTITY_URL/Consumer';

//Service Master
final String prefix = "api";
final String version = "v1";

//Configuration
// ignore: non_constant_identifier_names
final String ROOT_API_CONFIGURATION_URL =
    '/catalog.api/$prefix/$version/Configuration';
// ignore: non_constant_identifier_names
final String ROOT_API_PROVINCE_URL = '/catalog.api/$prefix/$version/Province';
// ignore: non_constant_identifier_names
final String ROOT_API_DISTRICT_URL = '/catalog.api/$prefix/$version/District';
// ignore: non_constant_identifier_names
final String ROOT_API_WARD_URL = '/catalog.api/$prefix/$version/Ward';
// ignore: non_constant_identifier_names
final String ROOT_API_SHIP_ADDRESS_URL =
    '/catalog.api/$prefix/$version/ShipAddress';

//NOTIFY
// ignore: non_constant_identifier_names
final String ROOT_API_NOTIFY_URL =
    '/catalog.api/$prefix/$version/NotifyMessage';
// ignore: non_constant_identifier_names
final String ROOT_API_NOTIFICATION_SUP_URL =
    '/catalog.api/$prefix/$version/NotificationSetup';

//CATALOGS
// ignore: non_constant_identifier_names
final String ROOT_API_CATALOGS_URL = '/catalog.api/$prefix/$version';

//VENDOR
// ignore: non_constant_identifier_names
final String ROOT_API_VENDOR_URL = '/catalog.api/$prefix/$version/Vendor';
// ignore: non_constant_identifier_names
final String ROOT_API_VENDOR_CONN_SHOP_URL =
    '/catalog.api/$prefix/$version/VendorsConnectShops';

//CUMULATIVE_GIFTS
// ignore: non_constant_identifier_names
final String ROOT_API_CUMULATIVE_GIFTS_URL =
    '/catalog.api/$prefix/$version/CumulativeGifts';

//FEEDBACK
// ignore: non_constant_identifier_names
final String ROOT_API_FEEDBACK_URL = '/catalog.api/$prefix/$version/Feedback';

//Service Shop
// ignore: non_constant_identifier_names
final String ROOT_API_SHOP_URL = '/catalog.api/$prefix/$version/Shop';

//Service Basket
// ignore: non_constant_identifier_names
final String ROOT_API_CART_URL = '/basket.api/$prefix/$version/Basket';

//Service Order
// ignore: non_constant_identifier_names
final String ROOT_API_ORDER_URL = '/ordering.api/$prefix/$version/Orders';

//Service Price
// ignore: non_constant_identifier_names
final String ROOT_API_PRICING_URL = '/pricing.api/$prefix/$version';

//Service Price
// ignore: non_constant_identifier_names
final String ROOT_API_CHAT_URL = '/chat.api/$prefix/$version';

//Service Product Search Azure
// ignore: non_constant_identifier_names
final String ROOT_SERVICE_PRODUCT_SEARCH_AZURE_URL =
    'https://productsearch.search.windows.net/indexes';
// ignore: non_constant_identifier_names
final String ROOT_SERVICE_PRODUCT_SEARCH_URL = '/catalog.api/$prefix/$version';

//QUERY_PARAM
// ignore: non_constant_identifier_names
final String QUERY_PARAM_LINK = "/";
// ignore: non_constant_identifier_names
final String QUERY_PARAM_REQUEST = "/?";
// ignore: non_constant_identifier_names
final String QUERY_PARAM_REQUEST_QUESTION_MARK = "?";
// ignore: non_constant_identifier_names
final String QUERY_PARAM_EQUAL = "=";
// ignore: non_constant_identifier_names
final String QUERY_PARAM_AND = "&";
// ignore: non_constant_identifier_names
final String USERNAME_PARAM = "userName";
// ignore: non_constant_identifier_names
final String PASSWORD_PARAM = "password";
// ignore: non_constant_identifier_names
final String IMEI_PARAM = "imei";
// ignore: non_constant_identifier_names
final String LOCALTIME_PARAM = "localTime";
// ignore: non_constant_identifier_names
final String LANGID_PARAM = "langID";
// ignore: non_constant_identifier_names
final String CURRENT_PASSWORD_PARAM = "currentPassword";
// ignore: non_constant_identifier_names
final String NEW_PASSWORD_PARAM = "newPassword";
// ignore: non_constant_identifier_names
final String VERSION_PARAM = "version";
// ignore: non_constant_identifier_names
final String SESSIONID_PARAM = "sessionID";
// ignore: non_constant_identifier_names
final String DATE_PARAM = "date";
// ignore: non_constant_identifier_names
final String COUNTRY_CODE_PARAM = "countryCode";
// ignore: non_constant_identifier_names
final String PHONE_PARAM = "phone";
// ignore: non_constant_identifier_names
final String OTP_PARAM = "otp";
